import { Component, OnInit } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { ApiService } from 'src/app/services/api.service';
import { Artist, Song, Album } from '../../classes/entities';

@Component({
  selector: 'app-albums',
  templateUrl: './albums.component.html',
  styleUrls: ['./albums.component.scss']
})
export class AlbumsComponent implements OnInit {

  albumData: Album;
  albums: Promise<Array<Album>>;
  songs: Array<Song>;
  artists: Array<Artist>;

  constructor(
    private api: ApiService,
    private route: ActivatedRoute
  ) { }

  ngOnInit() {

    this.route.paramMap.subscribe(params => {

      // If the id argument is given...
      if (params.has('id')) {

        // ... then get artist data ...
        this.api.getAlbum(Number(params.get('id'))).then(async res => {
          this.albumData = res;
          const songs = await this.api.getSong(res.song.join());
          this.songs = songs.length ? songs : [songs];
          const artists = await this.api.getArtist(res.artist.join());
          this.artists = artists.length ? artists : [artists];
        });

      } else {

        // Otherwise, get all artists and list them out.
        this.albums = this.api.getAllAlbums();

      }

    });

  }

}
