import { Component, OnInit } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { ApiService } from 'src/app/services/api.service';
import { Artist, Song, Album } from '../../classes/entities';

@Component({
  selector: 'app-artists',
  templateUrl: './artists.component.html',
  styleUrls: ['./artists.component.scss']
})
export class ArtistsComponent implements OnInit {

  artistData: Artist;
  artists: Promise<Array<Artist>>;
  songs: Array<Song>;
  albums: Array<Album>;

  constructor(
    private api: ApiService,
    private route: ActivatedRoute
  ) { }

  ngOnInit() {

    this.route.paramMap.subscribe(params => {

      // If the id argument is given...
      if (params.has('id')) {

        // ... then get artist data ...
        this.api.getArtist(Number(params.get('id'))).then(async res => {
          this.artistData = res;
          const songs = await this.api.getSong(res.songs.join());
          this.songs = songs.length ? songs : [songs];
          const albums = await this.api.getAlbum(res.albums.join());
          this.albums = albums.length ? albums : [albums];
        });

      } else {

        // Otherwise, get all artists and list them out.
        this.artists = this.api.getAllArtists();

      }

    });

  }

}
