import { Component, OnInit } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { ApiService } from 'src/app/services/api.service';
import { faMusic, faCompactDisc, faUser } from '@fortawesome/free-solid-svg-icons';
import { Song, Album, Artist } from '../../classes/entities';

@Component({
  selector: 'app-search',
  templateUrl: './search.component.html',
  styleUrls: ['./search.component.scss']
})
export class SearchComponent implements OnInit {

  // ? fontAwesome imports
  faMusic = faMusic;
  faCompactDisc = faCompactDisc;
  faUser = faUser;

  songs: Song[] = [];
  albums: Album[] = [];
  artists: Artist[] = [];

  dataLoaded = false;

  constructor(
    private route: ActivatedRoute,
    private api: ApiService
  ) { }

  ngOnInit() {

    this.route.paramMap.subscribe(params => {

      this.songs = [];
      this.albums = [];
      this.artists = [];

      this.api.search(params.get('query')).then(results => {

        if (results.length) {
          results.forEach(result => {
            if (result.type === 'Song') {
              this.songs.push(result);
            } else if (result.type === 'Album') {
              this.albums.push(result);
            } else if (result.type === 'Artist') {
              this.artists.push(result);
            }
          });
        } else {
          if (results.type === 'Song') {
            this.songs.push(results);
          } else if (results.type === 'Album') {
            this.albums.push(results);
          } else if (results.type === 'Artist') {
            this.artists.push(results);
          }
        }

        this.dataLoaded = true;

      });

    });
  }

}
