import { Component, OnInit, Input } from '@angular/core';
import { Song, Artist, Album } from '../../classes/entities';
import { faPlay, faPlayCircle, faCompactDisc } from '@fortawesome/free-solid-svg-icons';
import { AudioService } from 'src/app/services/audio.service';

@Component({
  selector: 'app-songlist',
  templateUrl: './songlist.component.html',
  styleUrls: ['./songlist.component.scss']
})
export class SonglistComponent implements OnInit {
  @Input() songs: any;

  songsInfo = [];
  currentSongId: number;

  // ? fontAwesome imports
  faPlay = faPlay;
  faPlayCircle = faPlayCircle;
  faCompactDisc = faCompactDisc;

  constructor(public audio: AudioService) { }

  ngOnInit() {

    this.currentSongId = this.audio.currentSong;
    this.audio.currentSong$.subscribe(id => this.currentSongId = id);

    this.songs.forEach(song => {
      const index = this.songsInfo.push({}) - 1;
      const result = {
        ...song,
        artistInfo: null as Artist,
        albumInfo: null as Album,
        duration: null as number
      };
      song.getArtist().then((artist: Artist) => {
        result.artistInfo = artist;

        song.getAlbum().then((album: Album) => {
          result.albumInfo = album;

          song.getDuration().then((duration: number) => {
            result.duration = duration;

            this.songsInfo[index] = result;
          });
        });
      });
    });
  }

}
