import { Injectable } from '@angular/core';
import { DataService } from './data.service';
import { EntityService } from './entity.service';

/** This class contains helper functions to retreive data from the api. */
@Injectable({
  providedIn: 'root'
})
export class ApiService {

  constructor(
    private data: DataService,
    private entityService: EntityService
  ) { }

  /**
   * This function gets one or multiple songs from the api's database.
   * @param id The id of the song. Either a number, a string with numbers by commas or the string 'all'.
   * @returns a promise. When resolved it contains either one Song entity or an array of Song entities.
   */
  async getSong(id: number | string): Promise<any> {
    // Retreive data from the api...
    const data = await this.data.getSong(id);
    // ... and convert that data to entities.
    return this.entityService.createEntityFromData(data);
  }

  /**
   * This function gets one or multiple artists from the api's database.
   * @param id The id of the song. Either a number, a string with numbers by commas or the string 'all'.
   * @returns a promise. When resolved it contains either one Artist entity or an array of Artist entities.
   */
  async getArtist(id: number | string): Promise<any> {
    // Retreive data from the api...
    const data = await this.data.getArtist(id);
    // ... and convert that data to entities.
    return this.entityService.createEntityFromData(data);
  }

  /**
   * This function gets one or multiple albums from the api's database.
   * @param id The id of the song. Either a number, a string with numbers by commas or the string 'all'.
   * @returns a promise. When resolved it contains either one Album entity or an array of Album entities.
   */
  async getAlbum(id: number | string): Promise<any> {
    // Retreive data from the api...
    const data = await this.data.getAlbum(id);
    // ... and convert that data to entities.
    return this.entityService.createEntityFromData(data);
  }

  /**
   * This function gets all albums from the api's database.
   * @returns a promise. When resolved it contains either one Album entity or an array of Album entities.
   */
  async getAllAlbums(): Promise<any> {
    // Retreive data from the api...
    const data = await this.data.getAllAlbums();
    // ... and convert that data to entities.
    return this.entityService.createEntityFromData(data);
  }

  /**
   * This function gets all albums from the api's database.
   * @returns a promise. When resolved it contains either one Album entity or an array of Album entities.
   */
  async getAllArtists(): Promise<any> {
    // Retreive data from the api...
    const data = await this.data.getAllArtists();
    // ... and convert that data to entities.
    return this.entityService.createEntityFromData(data);
  }

  async search(query: string) {
    const data = await this.data.search(query);

    return this.entityService.createEntityFromData(data);
  }
}
