import { Injectable } from '@angular/core';
import { DataService, ApiData } from './data.service';
import { AxiosResponse } from 'axios';
import { NotificationService } from './notification.service';

@Injectable({
  providedIn: 'root'
})
export class DownloadService {

  constructor(
    private data: DataService,
    private notification: NotificationService
  ) { }

  downloadQueue: Promise<AxiosResponse>[] = [];

  addQueueItem(id: string) {
    console.log(`downloading ${id}...`);

    this.data.download(id);
    const index = this.downloadQueue.push(this.data.download(id)) - 1;
    this.downloadQueue[index].then(res => {
      // tslint:disable-next-line: max-line-length
      this.notification.newNotification({ user: 'Download manager', message: `The song ${res.data.result.title} is downloaded successfully.`}, 100000);
      this.downloadQueue.splice(index, 1);
    });
  }

  getDownloadQueue() {
    return this.data.downloadqueue();
  }

  getVideoDetails(id: string): Promise<AxiosResponse<ApiData>> {
    return this.data.videoInfo(id);
  }

  async insertSong(formData: any) {
    const songResult = (await this.data.insert('songs')).data.result;
    this.data.update('songs', songResult.id, 'name', formData.song);
    this.data.update('songs', songResult.id, 'artist', formData.artist);
    this.data.update('songs', songResult.id, 'path', formData.path);
    this.data.update('songs', songResult.id, 'liked', false);
  }

  // Input like: "00:00:54.43"
  convertTimeToSeconds(input: string): number {
    if (typeof input === 'string') {
      const parts = input.split(/[\:\.]/);
      let total = 0;

      total += Number(parts[0]) * 60 * 60; // Hours
      total += Number(parts[1]) * 60; // Minutes
      total += Number(parts[2]); // Seconds
      total += Number(parts[3]) / 100; // Centiseconds

      return total;
    } else {
      return;
    }
  }
}
