import { Injectable } from '@angular/core';
import { Song, Album, Artist } from '../classes/entities';

@Injectable({
  providedIn: 'root'
})
export class EntityService {

  constructor() { }

  /**
   * This function takes api data and converts it into entities.
   * @param data The data from the api.
   * @returns either an array of entities or a single entity.
   */
  createEntityFromData(data: any) {
    // If data child is present...
    if (data.data) {

      // Prepare array for elements to be returned.
      const result = [];

      // For every entity in the api data.
      data.data.result.forEach((element: { type: any; }) => {
        // If the type is...
        switch (element.type) {
          // ... a song, add a song entity to the result array.
          case 'song':
            result.push(new Song({data: {result: [element]}}));
            break;

          // ... an artist, add an artist entity to the result array.
          case 'artist':
            result.push(new Artist({ data: { result: [element] } }));
            break;

          // ... an album, add an album entity to the result array.
          case 'album':
            result.push(new Album({ data: { result: [element] } }));
            break;

          // .. anything else, just ignore it.
          default:
            break;
        }

      }); // end result.forEach

      // Return the result array, if it has more than one item.
      return result.length > 1 ? result : result[0];

    } else {
      // ? Make sure that the data is in the correct format.
    }
  }
}
